| Home | Libraries | People | FAQ | More

## Interpreting these Results

In all of the following tables, the best performing result in each row, is assigned a relative value of "1" and shown in bold, so a score of "2" means "twice as slow as the best performing result". Actual timings in nano-seconds per function call are also shown in parenthesis. To make the results easier to read, they are color-coded as follows: the best result and everything within 20% of it is green, anything that's more than twice as slow as the best result is red, and results in between are blue.

Result were obtained on a system with an Intel core i7 4710MQ with 16Gb RAM and running either Windows 8.1 or Xubuntu Linux.

| Caution
As usual with performance results these should be taken with a large pinch of salt: relative performance is known to shift quite a bit depending upon the architecture of the particular test system used. Further more, our performance results were obtained using our own test data: these test values are designed to provide good coverage of our code and test all the appropriate corner cases. They do not necessarily represent "typical" usage: whatever that may be!